Changelog
=========

v0.2
----

* changed `ejabberdctl.py` constructor - host is now server and server is now host
  ie. the terminology is aligned with what those inputs mean.
  Also see `README`; `Host vs Server` information.

v0.1
----

* initial version
